# pymm-eventserver
Event Server to receive Micro-Manager events in python via zeromq

This module functions as a plugin for Micro-Manager and takes a lot of inspiration and some functionality from PycroManager (https://pycro-manager.readthedocs.io/en/latest/index.html)
